@@ -1,22 +1,22 @@
-/* $Id: disco_modify.h 3237 2007-05-30 17:17:45Z dlaniel $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -27,11 +27,11 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
-#include <lasso/xml/xml.h>
-#include <lasso/xml/disco_resource_id.h>
-#include <lasso/xml/disco_encrypted_resource_id.h>
+#include "xml.h"
+#include "disco_resource_id.h"
+#include "disco_encrypted_resource_id.h"
 
 #define LASSO_TYPE_DISCO_MODIFY (lasso_disco_modify_get_type())
 #define LASSO_DISCO_MODIFY(obj) \
@@ -42,7 +42,7 @@ extern "C" {
 #define LASSO_IS_DISCO_MODIFY_CLASS(klass) \
 	(G_TYPE_CHECK_CLASS_TYPE ((klass), LASSO_TYPE_DISCO_MODIFY))
 #define LASSO_DISCO_MODIFY_GET_CLASS(o) \
-	(G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_DISCO_MODIFY, LassoDiscoModifyClass)) 
+	(G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_DISCO_MODIFY, LassoDiscoModifyClass))
 
 typedef struct _LassoDiscoModify LassoDiscoModify;
 typedef struct _LassoDiscoModifyClass LassoDiscoModifyClass;
@@ -53,8 +53,8 @@ struct _LassoDiscoModify {
 	LassoDiscoResourceID *ResourceID;
 	LassoDiscoEncryptedResourceID *EncryptedResourceID;
 
-	GList *InsertEntry;
-	GList *RemoveEntry;
+	GList *InsertEntry; /* of LassoNode */
+	GList *RemoveEntry; /* of LassoNode */
 
 	char *id;
 };
@@ -67,8 +67,6 @@ LASSO_EXPORT GType lasso_disco_modify_get_type (void);
 
 LASSO_EXPORT LassoDiscoModify* lasso_disco_modify_new (void);
 
-LASSO_EXPORT LassoDiscoModify* lasso_disco_modify_new_from_message(const gchar *message);
-
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
