@@ -1,28 +1,30 @@
-/* $Id: disco_options.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/disco_options.h>
+#include "private.h"
+#include "disco_options.h"
+#include "./idwsf_strings.h"
 
 /**
  * SECTION:disco_options
@@ -30,7 +32,7 @@
  *
  * <figure><title>Schema fragment for disco:Options</title>
  * <programlisting><![CDATA[
- * 
+ *
  * <xs:element name="Options" type="OptionsType"/>
  * <xs:complexType name="OptionsType">
  *   <xs:sequence>
@@ -46,20 +48,14 @@
 /*****************************************************************************/
 
 static struct XmlSnippet schema_snippets[] = {
-	{ "Option", SNIPPET_LIST_CONTENT, G_STRUCT_OFFSET(LassoDiscoOptions, Option) },
-	{ NULL, 0, 0}
+	{ "Option", SNIPPET_LIST_CONTENT, G_STRUCT_OFFSET(LassoDiscoOptions, Option), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoDiscoOptions *node)
-{
-	node->Option = NULL;
-}
-
 static void
 class_init(LassoDiscoOptionsClass *klass)
 {
@@ -86,11 +82,12 @@ lasso_disco_options_get_type()
 			NULL,
 			sizeof(LassoDiscoOptions),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
-						   "LassoDiscoOptions", &this_info, 0);
+				"LassoDiscoOptions", &this_info, 0);
 	}
 	return this_type;
 }
