@@ -1,22 +1,22 @@
-/* $Id: disco_options.h 3237 2007-05-30 17:17:45Z dlaniel $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -27,9 +27,9 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
-#include <lasso/xml/xml.h>
+#include "xml.h"
 
 #define LASSO_TYPE_DISCO_OPTIONS (lasso_disco_options_get_type())
 #define LASSO_DISCO_OPTIONS(obj) \
@@ -41,7 +41,7 @@ extern "C" {
 #define LASSO_IS_DISCO_OPTIONS_CLASS(klass) \
 	(G_TYPE_CHECK_CLASS_TYPE ((klass), LASSO_TYPE_DISCO_OPTIONS))
 #define LASSO_DISCO_OPTIONS_GET_CLASS(o) \
-	(G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_DISCO_OPTIONS, LassoDiscoOptionsClass)) 
+	(G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_DISCO_OPTIONS, LassoDiscoOptionsClass))
 
 typedef struct _LassoDiscoOptions LassoDiscoOptions;
 typedef struct _LassoDiscoOptionsClass LassoDiscoOptionsClass;
@@ -49,7 +49,7 @@ typedef struct _LassoDiscoOptionsClass LassoDiscoOptionsClass;
 struct _LassoDiscoOptions {
 	LassoNode parent;
 
-	GList *Option;
+	GList *Option; /* of strings */
 };
 
 struct _LassoDiscoOptionsClass {
