@@ -1,22 +1,22 @@
-/* $Id: dst_modify.h 3437 2007-11-03 21:23:50Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -27,12 +27,12 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
-#include <lasso/xml/disco_encrypted_resource_id.h>
-#include <lasso/xml/disco_resource_id.h>
-#include <lasso/xml/dst_modification.h>
-#include <lasso/xml/xml.h>
+#include "disco_encrypted_resource_id.h"
+#include "disco_resource_id.h"
+#include "dst_modification.h"
+#include "xml.h"
 
 #define LASSO_TYPE_DST_MODIFY (lasso_dst_modify_get_type())
 #define LASSO_DST_MODIFY(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), \
@@ -42,7 +42,7 @@ extern "C" {
 #define LASSO_IS_DST_MODIFY(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), LASSO_TYPE_DST_MODIFY))
 #define LASSO_IS_DST_MODIFY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LASSO_TYPE_DST_MODIFY))
 #define LASSO_DST_MODIFY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), \
- LASSO_TYPE_DST_MODIFY, LassoDstModifyClass)) 
+			LASSO_TYPE_DST_MODIFY, LassoDstModifyClass))
 
 typedef struct _LassoDstModify LassoDstModify;
 typedef struct _LassoDstModifyClass LassoDstModifyClass;
@@ -53,7 +53,7 @@ struct _LassoDstModify {
 	/*< public >*/
 	LassoDiscoResourceID *ResourceID;
 	LassoDiscoEncryptedResourceID *EncryptedResourceID;
-	GList *Modification;
+	GList *Modification; /* of LassoNode */
 	GList *Extension; /* of xmlNode* */
 
 	char *id;
@@ -70,7 +70,7 @@ struct _LassoDstModifyClass {
 
 LASSO_EXPORT GType lasso_dst_modify_get_type(void);
 
-LASSO_EXPORT LassoDstModify* lasso_dst_modify_new(LassoDstModification *modification);
+LASSO_EXPORT LassoDstModify* lasso_dst_modify_new();
 
 #ifdef __cplusplus
 }
