@@ -1,22 +1,22 @@
-/* $Id: dst_query.h 3437 2007-11-03 21:23:50Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -27,12 +27,12 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
-#include <lasso/xml/disco_encrypted_resource_id.h>
-#include <lasso/xml/disco_resource_id.h>
-#include <lasso/xml/dst_query_item.h>
-#include <lasso/xml/xml.h>
+#include "disco_encrypted_resource_id.h"
+#include "disco_resource_id.h"
+#include "dst_query_item.h"
+#include "xml.h"
 
 #define LASSO_TYPE_DST_QUERY (lasso_dst_query_get_type())
 #define LASSO_DST_QUERY(obj) (G_TYPE_CHECK_INSTANCE_CAST((obj), \
@@ -42,7 +42,7 @@ extern "C" {
 #define LASSO_IS_DST_QUERY(obj) (G_TYPE_CHECK_INSTANCE_TYPE((obj), LASSO_TYPE_DST_QUERY))
 #define LASSO_IS_DST_QUERY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), LASSO_TYPE_DST_QUERY))
 #define LASSO_DST_QUERY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), \
- LASSO_TYPE_DST_QUERY, LassoDstQueryClass)) 
+			LASSO_TYPE_DST_QUERY, LassoDstQueryClass))
 
 typedef struct _LassoDstQuery LassoDstQuery;
 typedef struct _LassoDstQueryClass LassoDstQueryClass;
@@ -53,7 +53,7 @@ struct _LassoDstQuery {
 	/*< public >*/
 	LassoDiscoResourceID *ResourceID;
 	LassoDiscoEncryptedResourceID *EncryptedResourceID;
-	GList *QueryItem;
+	GList *QueryItem; /* of LassoNode */
 	GList *Extension; /* of xmlNode* */
 
 	char *id;
