@@ -1,28 +1,30 @@
-/* $Id: disco_svc_md_register.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: disco_svc_md_register.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "disco_svc_md_register.h"
+#include "./idwsf2_strings.h"
 #include "disco_svc_metadata.h"
 
 /**
@@ -50,10 +52,10 @@
 static struct XmlSnippet schema_snippets[] = {
 	{ "SvcMD", SNIPPET_LIST_NODES,
 		G_STRUCT_OFFSET(LassoIdWsf2DiscoSvcMDRegister, SvcMD),
-		"LassoIdWsf2DiscoSvcMetadata" },
+		"LassoIdWsf2DiscoSvcMetadata", NULL, NULL },
 	{ "attributes", SNIPPET_ATTRIBUTE | SNIPPET_ANY,
-		G_STRUCT_OFFSET(LassoIdWsf2DiscoSvcMDRegister, attributes) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2DiscoSvcMDRegister, attributes), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -66,7 +68,6 @@ static LassoNodeClass *parent_class = NULL;
 static void
 instance_init(LassoIdWsf2DiscoSvcMDRegister *node)
 {
-	node->SvcMD = NULL;
 	node->attributes = g_hash_table_new_full(
 		g_str_hash, g_str_equal, g_free, g_free);
 }
@@ -79,7 +80,7 @@ class_init(LassoIdWsf2DiscoSvcMDRegisterClass *klass)
 	parent_class = g_type_class_peek_parent(klass);
 	nclass->node_data = g_new0(LassoNodeClassData, 1);
 	lasso_node_class_set_nodename(nclass, "SvcMDRegister");
-	lasso_node_class_set_ns(nclass, LASSO_IDWSF2_DISCO_HREF, LASSO_IDWSF2_DISCO_PREFIX);
+	lasso_node_class_set_ns(nclass, LASSO_IDWSF2_DISCOVERY_HREF, LASSO_IDWSF2_DISCOVERY_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
 }
 
@@ -99,6 +100,7 @@ lasso_idwsf2_disco_svc_md_register_get_type()
 			sizeof(LassoIdWsf2DiscoSvcMDRegister),
 			0,
 			(GInstanceInitFunc) instance_init,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
@@ -121,6 +123,18 @@ lasso_idwsf2_disco_svc_md_register_new()
 }
 
 
+/**
+ * lasso_idwsf2_disco_svc_md_register_new_full:
+ * @service_type: the service type for the registered metadatas
+ * @abstract: the human description for the service
+ * @provider_id: the SAML provider id of the service
+ * @soap_endpoint: the SOAP endpoint URL for the service
+ *
+ * Create and initialize a complete message for registering new metadatas at a discovery service.
+ *
+ * Return value: a new filled and initialized #LassoIdWsf2DiscoSvcMDRegister if successfull, NULL
+ * otherwise.
+ */
 LassoIdWsf2DiscoSvcMDRegister*
 lasso_idwsf2_disco_svc_md_register_new_full(const gchar *service_type, const gchar *abstract,
 		const gchar *provider_id, const gchar *soap_endpoint)
