@@ -1,28 +1,30 @@
-/* $Id: dstref_data.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: dstref_data.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "dstref_data.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:dstref_data
@@ -49,12 +51,12 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "remaining", SNIPPET_ATTRIBUTE | SNIPPET_INTEGER | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2DstRefData, remaining) },
+		G_STRUCT_OFFSET(LassoIdWsf2DstRefData, remaining), NULL, NULL, NULL},
 	{ "nextOffset", SNIPPET_ATTRIBUTE | SNIPPET_INTEGER | SNIPPET_OPTIONAL_NEG,
-		G_STRUCT_OFFSET(LassoIdWsf2DstRefData, nextOffset) },
+		G_STRUCT_OFFSET(LassoIdWsf2DstRefData, nextOffset), NULL, NULL, NULL},
 	{ "setID", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2DstRefData, setID) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2DstRefData, setID), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -67,9 +69,7 @@ static LassoNodeClass *parent_class = NULL;
 static void
 instance_init(LassoIdWsf2DstRefData *node)
 {
-	node->remaining = 0;
 	node->nextOffset = -1;
-	node->setID = NULL;
 }
 
 static void
@@ -100,6 +100,7 @@ lasso_idwsf2_dstref_data_get_type()
 			sizeof(LassoIdWsf2DstRefData),
 			0,
 			(GInstanceInitFunc) instance_init,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_IDWSF2_DSTREF_ITEM_DATA,
