@@ -1,28 +1,30 @@
-/* $Id: ims_identity_mapping_request.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: ims_identity_mapping_request.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "ims_identity_mapping_request.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:ims_identity_mapping_request
@@ -48,10 +50,10 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "MappingInput", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoIdWsf2ImsIdentityMappingRequest, MappingInput) },
+		G_STRUCT_OFFSET(LassoIdWsf2ImsIdentityMappingRequest, MappingInput), NULL, NULL, NULL},
 	{ "attributes", SNIPPET_ATTRIBUTE | SNIPPET_ANY,
-		G_STRUCT_OFFSET(LassoIdWsf2ImsIdentityMappingRequest, attributes) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2ImsIdentityMappingRequest, attributes), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -64,7 +66,6 @@ static LassoNodeClass *parent_class = NULL;
 static void
 instance_init(LassoIdWsf2ImsIdentityMappingRequest *node)
 {
-	node->MappingInput = NULL;
 	node->attributes = g_hash_table_new_full(
 		g_str_hash, g_str_equal, g_free, g_free);
 }
@@ -97,6 +98,7 @@ lasso_idwsf2_ims_identity_mapping_request_get_type()
 			sizeof(LassoIdWsf2ImsIdentityMappingRequest),
 			0,
 			(GInstanceInitFunc) instance_init,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
