@@ -1,28 +1,30 @@
-/* $Id: is_help.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: is_help.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "is_help.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:is_help
@@ -47,12 +49,12 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "label", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2IsHelp, label) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsHelp, label), NULL, NULL, NULL},
 	{ "link", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2IsHelp, link) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsHelp, link), NULL, NULL, NULL},
 	{ "moreLink", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2IsHelp, moreLink) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2IsHelp, moreLink), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -62,13 +64,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoIdWsf2IsHelp *node)
-{
-	node->label = NULL;
-	node->link = NULL;
-	node->moreLink = NULL;
-}
 
 static void
 class_init(LassoIdWsf2IsHelpClass *klass)
@@ -97,7 +92,8 @@ lasso_idwsf2_is_help_get_type()
 			NULL,
 			sizeof(LassoIdWsf2IsHelp),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
