@@ -1,28 +1,30 @@
-/* $Id: is_inquiry.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: is_inquiry.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "is_inquiry.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:is_inquiry
@@ -55,18 +57,18 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "Help", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInquiry, Help) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsInquiry, Help), NULL, NULL, NULL},
 	{ "Select", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInquiry, Select) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsInquiry, Select), NULL, NULL, NULL},
 	{ "Confirm", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInquiry, Confirm) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsInquiry, Confirm), NULL, NULL, NULL},
 	{ "Text", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInquiry, Text) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsInquiry, Text), NULL, NULL, NULL},
 	{ "id", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInquiry, id) },
+		G_STRUCT_OFFSET(LassoIdWsf2IsInquiry, id), NULL, NULL, NULL},
 	{ "title", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2IsInquiry, title) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2IsInquiry, title), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -76,16 +78,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoIdWsf2IsInquiry *node)
-{
-	node->Help = NULL;
-	node->Select = NULL;
-	node->Confirm = NULL;
-	node->Text = NULL;
-	node->id = NULL;
-	node->title = NULL;
-}
 
 static void
 class_init(LassoIdWsf2IsInquiryClass *klass)
@@ -114,7 +106,8 @@ lasso_idwsf2_is_inquiry_get_type()
 			NULL,
 			sizeof(LassoIdWsf2IsInquiry),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
