@@ -1,28 +1,30 @@
-/* $Id: ps_object.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: ps_object.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "ps_object.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:ps_object
@@ -55,22 +57,22 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "ObjectID", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoIdWsf2PsObject, ObjectID) },
+		G_STRUCT_OFFSET(LassoIdWsf2PsObject, ObjectID), NULL, NULL, NULL},
 	{ "DisplayName", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoIdWsf2PsObject, DisplayName) },
+		G_STRUCT_OFFSET(LassoIdWsf2PsObject, DisplayName), NULL, NULL, NULL},
 	{ "Tag", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoIdWsf2PsObject, Tag) },
+		G_STRUCT_OFFSET(LassoIdWsf2PsObject, Tag), NULL, NULL, NULL},
 	{ "Object", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoIdWsf2PsObject, Object) },
+		G_STRUCT_OFFSET(LassoIdWsf2PsObject, Object), NULL, NULL, NULL},
 	{ "ObjectRef", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoIdWsf2PsObject, ObjectRef) },
+		G_STRUCT_OFFSET(LassoIdWsf2PsObject, ObjectRef), NULL, NULL, NULL},
 	{ "NodeType", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoIdWsf2PsObject, NodeType) },
+		G_STRUCT_OFFSET(LassoIdWsf2PsObject, NodeType), NULL, NULL, NULL},
 	{ "CreatedDateTime", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2PsObject, CreatedDateTime) },
+		G_STRUCT_OFFSET(LassoIdWsf2PsObject, CreatedDateTime), NULL, NULL, NULL},
 	{ "ModifiedDateTime", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2PsObject, ModifiedDateTime) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2PsObject, ModifiedDateTime), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -80,18 +82,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoIdWsf2PsObject *node)
-{
-	node->ObjectID = NULL;
-	node->DisplayName = NULL;
-	node->Tag = NULL;
-	node->Object = NULL;
-	node->ObjectRef = NULL;
-	node->NodeType = NULL;
-	node->CreatedDateTime = NULL;
-	node->ModifiedDateTime = NULL;
-}
 
 static void
 class_init(LassoIdWsf2PsObjectClass *klass)
@@ -120,7 +110,8 @@ lasso_idwsf2_ps_object_get_type()
 			NULL,
 			sizeof(LassoIdWsf2PsObject),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
