@@ -1,28 +1,30 @@
-/* $Id: sb2_target_identity.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: sb2_target_identity.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "sb2_target_identity.h"
+#include "./idwsf2_strings.h"
 
 /**
  * SECTION:sb2_target_identity
@@ -48,8 +50,10 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "attributes", SNIPPET_ATTRIBUTE | SNIPPET_ANY,
-		G_STRUCT_OFFSET(LassoIdWsf2Sb2TargetIdentity, attributes) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2Sb2TargetIdentity, attributes), NULL, NULL, NULL},
+	{ "", SNIPPET_LIST_NODES | SNIPPET_ANY, G_STRUCT_OFFSET(LassoIdWsf2Sb2TargetIdentity, any),
+		NULL, NULL, NULL },
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -94,6 +98,7 @@ lasso_idwsf2_sb2_target_identity_get_type()
 			sizeof(LassoIdWsf2Sb2TargetIdentity),
 			0,
 			(GInstanceInitFunc) instance_init,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
