@@ -1,28 +1,31 @@
-/* $Id: util_status.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: util_status.c,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "util_status.h"
+#include "./idwsf2_strings.h"
+#include "../../utils.h"
 
 /**
  * SECTION:util_status
@@ -56,14 +59,14 @@
 static struct XmlSnippet schema_snippets[] = {
 	{ "Status", SNIPPET_LIST_NODES,
 		G_STRUCT_OFFSET(LassoIdWsf2UtilStatus, Status),
-		"LassoIdWsf2UtilStatus" },
+		"LassoIdWsf2UtilStatus", NULL, NULL },
 	{ "code", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoIdWsf2UtilStatus, code) },
+		G_STRUCT_OFFSET(LassoIdWsf2UtilStatus, code), NULL, NULL, NULL},
 	{ "ref", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2UtilStatus, ref) },
+		G_STRUCT_OFFSET(LassoIdWsf2UtilStatus, ref), NULL, NULL, NULL},
 	{ "comment", SNIPPET_ATTRIBUTE | SNIPPET_OPTIONAL,
-		G_STRUCT_OFFSET(LassoIdWsf2UtilStatus, comment) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoIdWsf2UtilStatus, comment), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -73,14 +76,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoIdWsf2UtilStatus *node)
-{
-	node->Status = NULL;
-	node->code = NULL;
-	node->ref = NULL;
-	node->comment = NULL;
-}
 
 static void
 class_init(LassoIdWsf2UtilStatusClass *klass)
@@ -109,7 +104,8 @@ lasso_idwsf2_util_status_get_type()
 			NULL,
 			sizeof(LassoIdWsf2UtilStatus),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
@@ -130,3 +126,29 @@ lasso_idwsf2_util_status_new()
 {
 	return g_object_new(LASSO_TYPE_IDWSF2_UTIL_STATUS, NULL);
 }
+
+
+/**
+ * lasso_idwsf2_util_status_new_with_code:
+ * @code1: first level code
+ * @code2: second level code
+ *
+ * Creates a new #LassoIdWsf2UtilStatus containing code1 and if code2 is not-NULL a nested
+ * #LassoIdWsf2UtilStatus containing code2.
+ *
+ * Return value: a newly created #LassoIdWsf2UtilStatus object
+ **/
+LassoIdWsf2UtilStatus*
+lasso_idwsf2_util_status_new_with_code(const gchar *code1, const gchar *code2)
+{
+	LassoIdWsf2UtilStatus *status1 = lasso_idwsf2_util_status_new();
+
+	lasso_assign_string(status1->code, code1);
+	if (code2 != NULL) {
+		LassoIdWsf2UtilStatus *status2 = lasso_idwsf2_util_status_new();
+		lasso_assign_string(status2->code, code2);
+		lasso_list_add_gobject(status1->Status, status2);
+	}
+
+	return status1;
+}
