@@ -1,22 +1,22 @@
-/* $Id: is_select.h 3237 2007-05-30 17:17:45Z dlaniel $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -27,10 +27,10 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
-#include <lasso/xml/is_item.h>
-#include <lasso/xml/xml.h>
+#include "is_item.h"
+#include "xml.h"
 
 #define LASSO_TYPE_IS_SELECT (lasso_is_select_get_type())
 #define LASSO_IS_SELECT(obj) \
@@ -48,7 +48,7 @@ typedef struct _LassoIsSelectClass LassoIsSelectClass;
 struct _LassoIsSelect {
 	LassoNode parent; /* FIXME : must inherit of InquiryElement class */
 
-	GList *Item;
+	GList *Item; /* of LassoNode */
 
 	gboolean multiple;
 };
@@ -59,8 +59,7 @@ struct _LassoIsSelectClass {
 
 LASSO_EXPORT GType lasso_is_select_get_type(void);
 
-LASSO_EXPORT LassoIsSelect* lasso_is_select_new(LassoIsItem *item1, LassoIsItem *item2);
-	/* FIXME : choose proper names */
+LASSO_EXPORT LassoIsSelect* lasso_is_select_new(void);
 
 #ifdef __cplusplus
 }
