@@ -1,22 +1,22 @@
-/* $Id: lib_authn_request.h 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -27,11 +27,11 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
-#include <lasso/xml/samlp_request_abstract.h>
-#include <lasso/xml/lib_request_authn_context.h>
-#include <lasso/xml/lib_scoping.h>
+#include "samlp_request_abstract.h"
+#include "lib_request_authn_context.h"
+#include "lib_scoping.h"
 
 #define LASSO_TYPE_LIB_AUTHN_REQUEST (lasso_lib_authn_request_get_type())
 #define LASSO_LIB_AUTHN_REQUEST(obj) \
@@ -43,7 +43,7 @@ extern "C" {
 #define LASSO_IS_LIB_AUTHN_REQUEST_CLASS(klass) \
 	(G_TYPE_CHECK_CLASS_TYPE ((klass), LASSO_TYPE_LIB_AUTHN_REQUEST))
 #define LASSO_LIB_AUTHN_REQUEST_GET_CLASS(o) \
-	(G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_LIB_AUTHN_REQUEST, LassoLibAuthnRequestClass)) 
+	(G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_LIB_AUTHN_REQUEST, LassoLibAuthnRequestClass))
 
 typedef struct _LassoLibAuthnRequest LassoLibAuthnRequest;
 typedef struct _LassoLibAuthnRequestClass LassoLibAuthnRequestClass;
