@@ -1,22 +1,22 @@
-/* $Id: lib_idp_entries.h 3483 2008-02-18 17:29:50Z bdauvergne $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -27,10 +27,10 @@
 
 #ifdef __cplusplus
 extern "C" {
-#endif /* __cplusplus */ 
+#endif /* __cplusplus */
 
-#include <lasso/xml/xml.h>
-#include <lasso/xml/lib_idp_entry.h>
+#include "xml.h"
+#include "lib_idp_entry.h"
 
 #define LASSO_TYPE_LIB_IDP_ENTRIES (lasso_lib_idp_entries_get_type())
 #define LASSO_LIB_IDP_ENTRIES(obj) \
@@ -42,14 +42,14 @@ extern "C" {
 #define LASSO_IS_LIB_IDP_ENTRIES_CLASS(klass) \
 	(G_TYPE_CHECK_CLASS_TYPE ((klass), LASSO_TYPE_LIB_IDP_ENTRIES))
 #define LASSO_LIB_IDP_ENTRIES_GET_CLASS(o) \
-	(G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_LIB_IDP_ENTRIES, LassoLibIDPEntriesClass)) 
+	(G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_LIB_IDP_ENTRIES, LassoLibIDPEntriesClass))
 
 typedef struct _LassoLibIDPEntries LassoLibIDPEntries;
 typedef struct _LassoLibIDPEntriesClass LassoLibIDPEntriesClass;
 
 struct _LassoLibIDPEntries{
 	LassoNode parent;
-	
+
 	/*< public >*/
 	/* <xs:element ref="IDPEntry" maxOccurs="unbounded"/> */
 	GList *IDPEntry; /* of LassoLibIDPEntry */
