@@ -1,33 +1,34 @@
-/* $Id: lib_idp_entry.c 3704 2008-05-15 21:17:44Z fpeters $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/lib_idp_entry.h>
+#include "private.h"
+#include "lib_idp_entry.h"
 
 /**
  * SECTION:lib_idp_entry
  * @short_description: &lt;lib:IDPEntry&gt;
- * 
+ *
  * <figure><title>Schema fragment for lib:IDPEntry</title>
  * <programlisting><![CDATA[
  * <xs:element name="IDPEntry">
@@ -48,23 +49,16 @@
 /*****************************************************************************/
 
 static struct XmlSnippet schema_snippets[] = {
-	{ "ProviderID", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoLibIDPEntry, ProviderID) },
-	{ "ProviderName", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoLibIDPEntry, ProviderName) },
-	{ "Loc", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoLibIDPEntry, Loc) },
-	{ NULL, 0, 0}
+	{ "ProviderID", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoLibIDPEntry, ProviderID), NULL, NULL, NULL},
+	{ "ProviderName", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoLibIDPEntry, ProviderName), NULL, NULL, NULL},
+	{ "Loc", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoLibIDPEntry, Loc), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoLibIDPEntry *node)
-{
-	node->ProviderID = NULL;
-	node->ProviderName = NULL;
-	node->Loc = NULL;
-}
 
 static void
 class_init(LassoLibIDPEntryClass *klass)
@@ -92,7 +86,8 @@ lasso_lib_idp_entry_get_type()
 			NULL,
 			sizeof(LassoLibIDPEntry),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
@@ -105,7 +100,7 @@ lasso_lib_idp_entry_get_type()
  * lasso_lib_idp_entry_new:
  *
  * Creates a new #LassoLibIDPEntry object.
- * 
+ *
  * Return value: a newly created @LassoLibIDPEntry object
  **/
 LassoNode*
