@@ -1,29 +1,31 @@
-/* $Id: lib_status_response.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/lib_status_response.h>
+#include "private.h"
+#include "lib_status_response.h"
 #include <libxml/uri.h>
+#include "../utils.h"
 
 /**
  * SECTION:lib_status_response
@@ -43,7 +45,7 @@
  *     </xs:extension>
  *   </xs:complexContent>
  * </xs:complexType>
- * 
+ *
  * <xs:element name="ProviderID" type="md:entityIDType"/>
  * <xs:element name="RelayState" type="xs:string"/>
  * ]]></programlisting>
@@ -56,11 +58,11 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "Extension", SNIPPET_EXTENSION,
-		G_STRUCT_OFFSET(LassoLibStatusResponse, Extension) },
-	{ "ProviderID", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoLibStatusResponse, ProviderID) },
-	{ "Status", SNIPPET_NODE, G_STRUCT_OFFSET(LassoLibStatusResponse, Status) },
-	{ "RelayState", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoLibStatusResponse, RelayState) },
-	{ NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoLibStatusResponse, Extension), NULL, NULL, NULL},
+	{ "ProviderID", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoLibStatusResponse, ProviderID), NULL, NULL, NULL},
+	{ "Status", SNIPPET_NODE, G_STRUCT_OFFSET(LassoLibStatusResponse, Status), NULL, NULL, NULL},
+	{ "RelayState", SNIPPET_CONTENT, G_STRUCT_OFFSET(LassoLibStatusResponse, RelayState), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static struct QuerySnippet query_snippets[] = {
@@ -78,34 +80,26 @@ static struct QuerySnippet query_snippets[] = {
 
 static LassoNodeClass *parent_class = NULL;
 
-static gchar*
-build_query(LassoNode *node)
-{
-	return lasso_node_build_query_from_snippets(node);
-}
-
 static gboolean
 init_from_query(LassoNode *node, char **query_fields)
 {
 	LassoLibStatusResponse *response = LASSO_LIB_STATUS_RESPONSE(node);
+	gboolean rc;
 
 	response->Status = lasso_samlp_status_new();
-	lasso_node_init_from_query_fields(node, query_fields);
+	rc = parent_class->init_from_query(node, query_fields);
 	if (response->ProviderID == NULL || response->Status == NULL)
 		return FALSE;
-	
+
 	if (response->Status->StatusCode) {
 		LassoSamlpStatusCode *code = response->Status->StatusCode;
 		if (code->Value && strchr(code->Value, ':') == NULL) {
-			char *s;  /* if not a QName; add the samlp prefix */
-			s = g_strdup_printf("samlp:%s", code->Value);
-			g_free(code->Value);
-			code->Value = s;
+			lasso_assign_string(code->Value,
+					g_strdup_printf("samlp:%s", code->Value));
 		}
 	}
 
-	
-	return TRUE;
+	return rc;
 }
 
 
@@ -114,13 +108,6 @@ init_from_query(LassoNode *node, char **query_fields)
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoLibStatusResponse *node)
-{
-	node->ProviderID = NULL;
-	node->Status = NULL;
-	node->RelayState = NULL;
-}
 
 static void
 class_init(LassoLibStatusResponseClass *klass)
@@ -128,7 +115,6 @@ class_init(LassoLibStatusResponseClass *klass)
 	LassoNodeClass *nclass = LASSO_NODE_CLASS(klass);
 
 	parent_class = g_type_class_peek_parent(klass);
-	nclass->build_query = build_query;
 	nclass->init_from_query = init_from_query;
 	nclass->node_data = g_new0(LassoNodeClassData, 1);
 	lasso_node_class_set_nodename(nclass, "StatusResponse");
@@ -152,7 +138,8 @@ lasso_lib_status_response_get_type()
 			NULL,
 			sizeof(LassoLibStatusResponse),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		status_response_type = g_type_register_static(LASSO_TYPE_SAMLP_RESPONSE_ABSTRACT,
