@@ -1,22 +1,22 @@
-/* $Id: misc_text_node.h,v 1.0 2005/10/14 15:17:55 fpeters Exp $ 
+/* $Id: misc_text_node.h,v 1.0 2005/10/14 15:17:55 fpeters Exp $
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -29,7 +29,7 @@
 extern "C" {
 #endif /* __cplusplus */
 
-#include <lasso/xml/xml.h>
+#include "xml.h"
 
 #define LASSO_TYPE_MISC_TEXT_NODE (lasso_misc_text_node_get_type())
 #define LASSO_MISC_TEXT_NODE(obj) \
@@ -44,7 +44,7 @@ extern "C" {
 	(G_TYPE_CHECK_CLASS_TYPE ((klass), LASSO_TYPE_MISC_TEXT_NODE))
 #define LASSO_MISC_TEXT_NODE_GET_CLASS(o) \
 	(G_TYPE_INSTANCE_GET_CLASS ((o), LASSO_TYPE_MISC_TEXT_NODE, \
-				LassoMiscTextNodeClass)) 
+				LassoMiscTextNodeClass))
 
 typedef struct _LassoMiscTextNode LassoMiscTextNode;
 typedef struct _LassoMiscTextNodeClass LassoMiscTextNodeClass;
@@ -68,10 +68,18 @@ struct _LassoMiscTextNodeClass {
 	LassoNodeClass parent;
 };
 
+LASSO_EXPORT void lasso_misc_text_node_set_xml_content(LassoMiscTextNode *misc_text_node,
+		xmlNode *node);
+
+LASSO_EXPORT xmlNode* lasso_misc_text_node_get_xml_content(LassoMiscTextNode *misc_text_node);
+
 LASSO_EXPORT GType lasso_misc_text_node_get_type(void);
+
 LASSO_EXPORT LassoNode* lasso_misc_text_node_new(void);
 
-LASSO_EXPORT LassoNode* lasso_misc_text_node_new_with_string(char *content);
+LASSO_EXPORT LassoMiscTextNode* lasso_misc_text_node_new_with_string(const char *content);
+
+LASSO_EXPORT LassoMiscTextNode* lasso_misc_text_node_new_with_xml_node(xmlNode *xml_node);
 
 
 #ifdef __cplusplus
