@@ -1,27 +1,28 @@
-/* $Id: saml2_evidence.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
+#include "../private.h"
 #include "saml2_evidence.h"
 
 /**
@@ -50,14 +51,14 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "AssertionIDRef", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoSaml2Evidence, AssertionIDRef) },
+		G_STRUCT_OFFSET(LassoSaml2Evidence, AssertionIDRef), NULL, NULL, NULL},
 	{ "AssertionURIRef", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoSaml2Evidence, AssertionURIRef) },
+		G_STRUCT_OFFSET(LassoSaml2Evidence, AssertionURIRef), NULL, NULL, NULL},
 	{ "Assertion", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoSaml2Evidence, Assertion) },
+		G_STRUCT_OFFSET(LassoSaml2Evidence, Assertion), NULL, NULL, NULL},
 	{ "EncryptedAssertion", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoSaml2Evidence, EncryptedAssertion) },
-	{NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoSaml2Evidence, EncryptedAssertion), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 static LassoNodeClass *parent_class = NULL;
@@ -67,14 +68,6 @@ static LassoNodeClass *parent_class = NULL;
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSaml2Evidence *node)
-{
-	node->AssertionIDRef = NULL;
-	node->AssertionURIRef = NULL;
-	node->Assertion = NULL;
-	node->EncryptedAssertion = NULL;
-}
 
 static void
 class_init(LassoSaml2EvidenceClass *klass)
@@ -83,7 +76,7 @@ class_init(LassoSaml2EvidenceClass *klass)
 
 	parent_class = g_type_class_peek_parent(klass);
 	nclass->node_data = g_new0(LassoNodeClassData, 1);
-	lasso_node_class_set_nodename(nclass, "Evidence"); 
+	lasso_node_class_set_nodename(nclass, "Evidence");
 	lasso_node_class_set_ns(nclass, LASSO_SAML2_ASSERTION_HREF, LASSO_SAML2_ASSERTION_PREFIX);
 	lasso_node_class_add_snippets(nclass, schema_snippets);
 }
@@ -103,7 +96,8 @@ lasso_saml2_evidence_get_type()
 			NULL,
 			sizeof(LassoSaml2Evidence),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
