@@ -1,29 +1,30 @@
-/* $Id: saml_advice.c 3704 2008-05-15 21:17:44Z fpeters $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/saml_advice.h>
-#include <lasso/xml/saml_assertion.h>
+#include "private.h"
+#include "saml_advice.h"
+#include "saml_assertion.h"
 
 /**
  * SECTION:saml_advice
@@ -39,7 +40,7 @@
  *     <any namespace="##other" processContents="lax"/>
  *   </choice>
  * </complexType>
- * 
+ *
  * <element name="AssertionIDReference" type="saml:IDReferenceType"/>
  * <simpleType name="IDReferenceType">
  *   <restriction base="string"/>
@@ -49,26 +50,20 @@
  */
 
 /*****************************************************************************/
-/* private methods                                                           */
+/* private methods	                                                   */
 /*****************************************************************************/
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "AssertionIDReference", SNIPPET_LIST_CONTENT,
-		G_STRUCT_OFFSET(LassoSamlAdvice, AssertionIDReference) },
-	{ "Assertion", SNIPPET_NODE, G_STRUCT_OFFSET(LassoSamlAdvice, Assertion) },
-	{ NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoSamlAdvice, AssertionIDReference), NULL, NULL, NULL},
+	{ "Assertion", SNIPPET_NODE, G_STRUCT_OFFSET(LassoSamlAdvice, Assertion), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
-/* instance and class init functions                                         */
+/* instance and class init functions	                                 */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSamlAdvice *node)
-{
-	node->AssertionIDReference = NULL;
-	node->Assertion = NULL;
-}
 
 static void
 class_init(LassoSamlAdviceClass *klass)
@@ -96,7 +91,8 @@ lasso_saml_advice_get_type()
 			NULL,
 			sizeof(LassoSamlAdvice),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_NODE,
@@ -107,7 +103,7 @@ lasso_saml_advice_get_type()
 
 /**
  * lasso_saml_advice_new:
- * 
+ *
  * Creates a new #LassoSamlAdvice object.
  *
  * Return value: a newly created #LassoSamlAdvice
