@@ -1,32 +1,39 @@
-/* $Id: saml_attribute_statement.c 3237 2007-05-30 17:17:45Z dlaniel $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/saml_attribute_statement.h>
+#include "private.h"
+#include "saml_attribute_statement.h"
 
-/*
+/**
+ * SECTION:saml_attribute_statement
+ * @short_description: object mapping for a saml:AttributeStatement
+ *
  * The schema fragment (oasis-sstc-saml-schema-assertion-1.1.xsd):
- * 
+ * <figure>
+ * <title>Schema fragment for saml:AttributeStatement</title>
+ * <programlisting>
+ * <![CDATA[
  * <element name="AttributeStatement" type="saml:AttributeStatementType"/>
  * <complexType name="AttributeStatementType">
  *   <complexContent>
@@ -37,6 +44,9 @@
  *     </extension>
  *   </complexContent>
  * </complexType>
+ * ]]>
+ * </programlisting>
+ * </figure>
  */
 
 /*****************************************************************************/
@@ -45,19 +55,14 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "Attribute", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoSamlAttributeStatement, Attribute) },
-	{ NULL, 0, 0 }
+		G_STRUCT_OFFSET(LassoSamlAttributeStatement, Attribute), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSamlAttributeStatement *node)
-{
-	node->Attribute = NULL;
-}
 
 static void
 class_init(LassoSamlAttributeStatementClass *klass)
@@ -85,21 +90,22 @@ lasso_saml_attribute_statement_get_type()
 			NULL,
 			sizeof(LassoSamlAttributeStatement),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_SAML_SUBJECT_STATEMENT_ABSTRACT,
-						   "LassoSamlAttributeStatement",
-						   &this_info, 0);
+				"LassoSamlAttributeStatement",
+				&this_info, 0);
 	}
 	return this_type;
 }
 
 /**
  * lasso_saml_attribute_statement_new:
- * 
+ *
  * Creates a new #LassoSamlAttributeStatement object.
- * 
+ *
  * Return value: a newly created #LassoSamlAttributeStatement object
  **/
 LassoSamlAttributeStatement*
