@@ -1,28 +1,29 @@
-/* $Id: saml_authentication_statement.c 3704 2008-05-15 21:17:44Z fpeters $
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/saml_authentication_statement.h>
+#include "private.h"
+#include "saml_authentication_statement.h"
 
 /**
  * SECTION:saml_authentication_statement
@@ -30,7 +31,7 @@
  *
  * <figure><title>Schema fragment for saml:AuthenticationStatement</title>
  * <programlisting><![CDATA[
- * 
+ *
  * <element name="AuthenticationStatement" type="saml:AuthenticationStatementType"/>
  * <complexType name="AuthenticationStatementType">
  *   <complexContent>
@@ -54,28 +55,20 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "SubjectLocality", SNIPPET_NODE,
-		G_STRUCT_OFFSET(LassoSamlAuthenticationStatement, SubjectLocality) },
+		G_STRUCT_OFFSET(LassoSamlAuthenticationStatement, SubjectLocality), NULL, NULL, NULL},
 	{ "AuthorityBinding", SNIPPET_LIST_NODES,
-		G_STRUCT_OFFSET(LassoSamlAuthenticationStatement, AuthorityBinding) },
+		G_STRUCT_OFFSET(LassoSamlAuthenticationStatement, AuthorityBinding), NULL, NULL, NULL},
 	{ "AuthenticationMethod", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoSamlAuthenticationStatement, AuthenticationMethod) },
+		G_STRUCT_OFFSET(LassoSamlAuthenticationStatement, AuthenticationMethod), NULL, NULL, NULL},
 	{ "AuthenticationInstant", SNIPPET_ATTRIBUTE,
-		G_STRUCT_OFFSET(LassoSamlAuthenticationStatement, AuthenticationInstant) },
-	{ NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoSamlAuthenticationStatement, AuthenticationInstant), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSamlAuthenticationStatement *node)
-{
-	node->SubjectLocality = NULL;
-	node->AuthorityBinding = NULL;
-	node->AuthenticationMethod = NULL;
-	node->AuthenticationInstant = NULL;
-}
 
 static void
 class_init(LassoSamlAuthenticationStatementClass *klass)
@@ -103,7 +96,8 @@ lasso_saml_authentication_statement_get_type()
 			NULL,
 			sizeof(LassoSamlAuthenticationStatement),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_SAML_SUBJECT_STATEMENT_ABSTRACT,
@@ -116,7 +110,7 @@ lasso_saml_authentication_statement_get_type()
  * lasso_saml_authentication_statement_new:
  *
  * Creates a new #LassoSamlAuthenticationStatement object.
- * 
+ *
  * Return value: a newly created #LassoSamlAuthenticationStatement object
  **/
 LassoNode*
