@@ -1,34 +1,35 @@
-/* $Id: samlp_request.c 3704 2008-05-15 21:17:44Z fpeters $ 
+/* $Id$
  *
  * Lasso - A free implementation of the Liberty Alliance specifications.
  *
  * Copyright (C) 2004-2007 Entr'ouvert
  * http://lasso.entrouvert.org
- * 
+ *
  * Authors: See AUTHORS file in top-level directory.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include <lasso/xml/samlp_request.h>
+#include "private.h"
+#include "samlp_request.h"
 
 /**
  * SECTION:samlp_request
  * @short_description: &lt;samlp:Request&gt;
  *
- * <figure><title>Schema fragment for lib:Scoping</title>
+ * <figure><title>Schema fragment for samlp:Request</title>
  * <programlisting><![CDATA[
  * <element name="Request" type="samlp:RequestType"/>
  * <complexType name="RequestType">
@@ -46,8 +47,7 @@
  *      </extension>
  *    </complexContent>
  * </complexType>
- * 
- * <element name="AssertionArtifact" type="string"/>
+ *
  * ]]></programlisting>
  * </figure>
  */
@@ -58,19 +58,14 @@
 
 static struct XmlSnippet schema_snippets[] = {
 	{ "AssertionArtifact", SNIPPET_CONTENT,
-		G_STRUCT_OFFSET(LassoSamlpRequest, AssertionArtifact) },
-	{ NULL, 0, 0}
+		G_STRUCT_OFFSET(LassoSamlpRequest, AssertionArtifact), NULL, NULL, NULL},
+	{NULL, 0, 0, NULL, NULL, NULL}
 };
 
 /*****************************************************************************/
 /* instance and class init functions                                         */
 /*****************************************************************************/
 
-static void
-instance_init(LassoSamlpRequest *node)
-{
-	node->AssertionArtifact = NULL;
-}
 
 static void
 class_init(LassoSamlpRequestClass *klass)
@@ -98,7 +93,8 @@ lasso_samlp_request_get_type()
 			NULL,
 			sizeof(LassoSamlpRequest),
 			0,
-			(GInstanceInitFunc) instance_init,
+			NULL,
+			NULL
 		};
 
 		this_type = g_type_register_static(LASSO_TYPE_SAMLP_REQUEST_ABSTRACT,
