@@ -26,14 +26,18 @@
 
 #include <check.h>
 
-#include <lasso/lasso.h>
-#include <lasso/id-ff/provider.h>
+#include <../lasso/lasso.h>
+#include <../lasso/id-ff/provider.h>
+#include "../lasso/utils.h"
+#include "./tests.h"
+#include "../lasso/xml/saml-2.0/saml2_xsd.h"
 
 START_TEST(test01_metadata_load_der_certificate_from_x509_cert)
 {
 	LassoProvider *provider = lasso_provider_new(LASSO_PROVIDER_ROLE_SP,
 			TESTSMETADATADIR "/metadata_01.xml", NULL, NULL);
 	fail_unless(provider != NULL, "Can't load DER certificate from <ds:X509Certificate>");
+	g_object_unref(provider);
 }
 END_TEST
 
@@ -42,6 +46,7 @@ START_TEST(test02_metadata_load_pem_certificate_from_x509_cert)
 	LassoProvider *provider = lasso_provider_new(LASSO_PROVIDER_ROLE_SP,
 			TESTSMETADATADIR "/metadata_02.xml", NULL, NULL);
 	fail_unless(provider != NULL, "Can't load PEM certificate from <ds:X509Certificate>");
+	g_object_unref(provider);
 }
 END_TEST
 
@@ -50,6 +55,7 @@ START_TEST(test03_metadata_load_der_public_key_from_keyvalue)
 	LassoProvider *provider = lasso_provider_new(LASSO_PROVIDER_ROLE_SP,
 			TESTSMETADATADIR "/metadata_03.xml", NULL, NULL);
 	fail_unless(provider != NULL, "Can't load DER public key from <ds:KeyValue>");
+	g_object_unref(provider);
 }
 END_TEST
 
@@ -58,6 +64,7 @@ START_TEST(test04_metadata_load_pem_public_key_from_keyvalue)
 	LassoProvider *provider = lasso_provider_new(LASSO_PROVIDER_ROLE_SP,
 			TESTSMETADATADIR "/metadata_04.xml", NULL, NULL);
 	fail_unless(provider != NULL, "Can't load PEM public key from <ds:KeyValue>");
+	g_object_unref(provider);
 }
 END_TEST
 
@@ -66,9 +73,46 @@ START_TEST(test05_metadata_load_public_key_from_x509_cert)
 	LassoProvider *provider = lasso_provider_new(LASSO_PROVIDER_ROLE_SP,
 			TESTSMETADATADIR "/metadata_05.xml", NULL, NULL);
 	fail_unless(provider != NULL, "Can't load DER public key from <ds:X509Certificate>");
+	g_object_unref(provider);
 }
 END_TEST
 
+START_TEST(test06_metadata_load_public_key_from_rsa_keyvalue)
+{
+	LassoProvider *provider = lasso_provider_new(LASSO_PROVIDER_ROLE_SP,
+			TESTSMETADATADIR "/metadata_06.xml", NULL, NULL);
+	fail_unless(provider != NULL, "Can't load RSAKeyValue node");
+	g_object_unref(provider);
+}
+END_TEST
+
+START_TEST(test07_metadata_role_descriptors)
+{
+	LassoProvider *provider = (LassoProvider*)lasso_provider_new(LASSO_PROVIDER_ROLE_IDP, TESTSDATADIR "/idp6-saml2/metadata.xml",
+			NULL, NULL);
+	GList *l;
+	int i = 0;
+
+	check_not_null(provider);
+	for (i = 1; i < LASSO_PROVIDER_ROLE_LAST; i *= 2) {
+		l = lasso_provider_get_metadata_keys_for_role(provider, i);
+		if (i == LASSO_PROVIDER_ROLE_IDP) {
+			check_equals(g_list_length(l), 10);
+		} else if (i == LASSO_PROVIDER_ROLE_AUTHN_AUTHORITY ||
+				i == LASSO_PROVIDER_ROLE_AUTHZ_AUTHORITY ||
+				i == LASSO_PROVIDER_ROLE_ATTRIBUTE_AUTHORITY) {
+			check_equals(g_list_length(l), 3);
+		}
+		lasso_release_list_of_strings(l);
+	}
+	l = lasso_provider_get_metadata_list_for_role(provider, LASSO_PROVIDER_ROLE_IDP,
+			LASSO_SAML2_METADATA_ATTRIBUTE_WANT_AUTHN_REQUEST_SIGNED);
+	check_not_null(l);
+	check_null(l->next);
+	check_str_equals(l->data, "true");
+	lasso_release_gobject(provider);
+}
+END_TEST
 
 Suite*
 metadata_suite()
@@ -84,11 +128,18 @@ metadata_suite()
 		tcase_create("Load PEM public key from <ds:KeyValue>");
 	TCase *tc_metadata_load_public_key_from_x509_cert =
 		tcase_create("Load DER public key from <ds:X509Certificate>");
+	TCase *tc_metadata_load_public_key_from_rsa_keyvalue =
+		tcase_create("Load RSAKeyValue public key");
+	TCase *tc_metadata_role_descriptors =
+		tcase_create("Lookup different role descriptors datas");
+
 	suite_add_tcase(s, tc_metadata_load_der_certificate_from_x509_cert);
 	suite_add_tcase(s, tc_metadata_load_pem_certificate_from_x509_cert);
 	suite_add_tcase(s, tc_metadata_load_der_public_key_from_keyvalue);
 	suite_add_tcase(s, tc_metadata_load_pem_public_key_from_keyvalue);
 	suite_add_tcase(s, tc_metadata_load_public_key_from_x509_cert);
+	suite_add_tcase(s, tc_metadata_load_public_key_from_rsa_keyvalue);
+	suite_add_tcase(s, tc_metadata_role_descriptors);
 	tcase_add_test(tc_metadata_load_der_certificate_from_x509_cert,
 		test01_metadata_load_der_certificate_from_x509_cert);
 	tcase_add_test(tc_metadata_load_pem_certificate_from_x509_cert,
@@ -99,5 +150,9 @@ metadata_suite()
 		test04_metadata_load_pem_public_key_from_keyvalue);
 	tcase_add_test(tc_metadata_load_public_key_from_x509_cert,
 		test05_metadata_load_public_key_from_x509_cert);
+	tcase_add_test(tc_metadata_load_public_key_from_rsa_keyvalue,
+		test06_metadata_load_public_key_from_rsa_keyvalue);
+	tcase_add_test(tc_metadata_role_descriptors,
+			test07_metadata_role_descriptors);
 	return s;
 }
